@@ -13,6 +13,7 @@ from .utils import merge_desc, serialize_tags, deserialize_tags, todo_to_dict_wi
 from tabulate import tabulate
 
 app = typer.Typer(name='todo')
+app.add_typer(config.app, name='config')
 
 
 def _version_callback(value: bool) -> None:
@@ -21,15 +22,16 @@ def _version_callback(value: bool) -> None:
         raise typer.Exit()
 
 
+init_db_path_opt = typer.Option(
+    DEFAULT_DB_FILE_PATH,
+    "--db-path",
+    "-db",
+    prompt="to-do database location?",
+)
+
+
 @app.command()
-def init(
-    db_path: Path = typer.Option(
-        DEFAULT_DB_FILE_PATH,
-        "--db-path",
-        "-db",
-        prompt="to-do database location?",
-    ),
-) -> None:
+def init(db_path: Path = init_db_path_opt) -> None:
     """Initialize the to-do database."""
     app_init_error = config.init_app(db_path)
     if app_init_error:
@@ -52,12 +54,7 @@ def init(
 
 @app.command()
 def re_init(
-    db_path: Path = typer.Option(
-        DEFAULT_DB_FILE_PATH,
-        "--db-path",
-        "-db",
-        prompt="to-do database location?",
-    ),
+    db_path: Path = init_db_path_opt,
     force: bool = typer.Option(False,
                                "--force",
                                "-f",
@@ -83,7 +80,7 @@ def re_init(
 
 
 @app.command('a')
-@app.command()
+# @app.command()
 def add(
         description: list[str] = typer.Argument(...),
         priority: Priority = typer.Option(Priority.MEDIUM,
@@ -129,24 +126,19 @@ def add(
                     err=True)
 
 
-@app.command(name="list")
+# @app.command(name="list")
 @app.command(name="ls")
 def list_all() -> None:
     """list all to-dos."""
     with Session(engine) as session:
         todos = session.query(Todo).all()
         todo_list = [todo_to_dict_with_project_name(x) for x in todos]
-    # for x in todos:
-    #     print(x)
-    #     print(x.__dict__)
-    #     return
     if len(todo_list) == 0:
         typer.secho("There are no tasks in the to-do list yet",
                     fg=typer.colors.RED,
                     err=True)
         raise typer.Exit()
     typer.secho("\nto-do list:\n", fg=typer.colors.BLUE, bold=True)
-    # tabulate(todo_list, headers=['id', 'description', 'priority', 'status', 'project', 'tags', 'due_date'])
     table = tabulate(todo_list, headers='keys')
     typer.secho(table)
 
@@ -157,7 +149,7 @@ def list_all() -> None:
 
 
 @app.command(name='g')
-@app.command(name='get')
+# @app.command(name='get')
 def get_todo(todo_id: int) -> None:
     """Get a to-do by ID."""
     with Session(engine) as session:
@@ -186,7 +178,7 @@ def _get_todo(todo_id, session, output: bool = False) -> Todo:
 
 
 @app.command(name='m')
-@app.command(name='modify')
+# @app.command(name='modify')
 def modify(
         # ctx: typer.Context,
         todo_id: int = typer.Argument(...),
@@ -241,7 +233,7 @@ def modify(
 
 
 @app.command('rm')
-@app.command()
+# @app.command()
 def remove(
     todo_id: int = typer.Argument(...),
     force: bool = typer.Option(
@@ -291,6 +283,9 @@ def main(version: bool = typer.Option(
     callback=_version_callback,
     is_eager=True,
 )) -> None:
+    """
+    tddschn's command line todo app
+    """
     return
 
 
